import { createOverlayComponent } from '@react-leaflet/core';
import { Popup as LeafletPopup } from 'leaflet';
import { useEffect } from 'react';
export const Popup = createOverlayComponent(function createPopup(props, context) {
  return {
    instance: new LeafletPopup(props, context.overlayContainer),
    context
  };
}, function usePopupLifecycle(element, context, props, setOpen) {
  const {
    onClose,
    onOpen,
    position
  } = props;
  useEffect(function addPopup() {
    const {
      instance
    } = element;

    function onPopupOpen(event) {
      if (event.popup === instance) {
        instance.update();
        setOpen(true);
        onOpen?.();
      }
    }

    function onPopupClose(event) {
      if (event.popup === instance) {
        setOpen(false);
        onClose?.();
      }
    }

    context.map.on({
      // @ts-ignore emits PopupEvent instead of LeafletEvent
      popupopen: onPopupOpen,
      // @ts-ignore emits PopupEvent instead of LeafletEvent
      popupclose: onPopupClose
    });

    if (context.overlayContainer == null) {
      // Attach to a Map
      if (position != null) {
        instance.setLatLng(position);
      }

      instance.openOn(context.map);
    } else {
      // Attach to container component
      context.overlayContainer.bindPopup(instance);
    }

    return function removePopup() {
      context.map.off({
        // @ts-ignore emits PopupEvent instead of LeafletEvent
        popupopen: onPopupOpen,
        // @ts-ignore emits PopupEvent instead of LeafletEvent
        popupclose: onPopupClose
      });

      if (context.overlayContainer == null) {
        context.map.removeLayer(instance);
      } else {
        context.overlayContainer.unbindPopup();
      }
    };
  }, [element, context, setOpen, onClose, onOpen, position]);
});